@@ -6,6 +6,7 @@
 #include <qcolor.h>
 #include <qpainter.h>
 #include <qstringlist.h>
+#include <qdom.h>
 #include "Point.h"
 
 class LImage
@@ -15,11 +16,16 @@ public:
 	QStringList Info();
 	void save(QTextStream *t);
 	void open(QTextStream *t,int version);
+	QDomElement saveXML(QDomDocument doc);
+	void openXML(QDomNode node);
 	Point Pos() { return pos; }
 	void setPos(double x, double y) { pos=Point(x,y);}
 	QString Name() { return name; }
+	void setName(QString n) { name=n; }
 	double Scale() { return scale; }
+	void setScale(double s) { scale=s; }
 	double Angle() { return angle; }
+	void setAngle(double a) { angle=a; }
 	void draw(QPainter *p, double w, double h);
 	bool inside(int x, int y, int w, int h);
 protected:
