@@ -13,6 +13,8 @@ class Plot2DSimple:public Plot2D {
 public:
 	Plot2DSimple(Worksheet *p);
 	QStringList Info();
+	void calculateXY(Point d,double *x, double *y, int w, int h);
+	void drawFill(QPainter *p, int w, int h);
 	void drawCurves(QPainter *p, int w, int h);
 };
 
