@@ -11,34 +11,38 @@ using namespace std;
 Plot3D::Plot3D(Worksheet *p)
 	: Plot(p) 
 {
-	title = new Label(i18n("Title 3D"),QFont("Adobe Times",22),QColor(Qt::black));
+	QFont font = p->getMainWin()->defaultFont();
+	font.setPointSize((int)(0.7*font.pointSize()));	// for axes label
+	title = new Label(i18n("Title 3D"),font,QColor(Qt::black));
 	title->setPosition(0.4,0.04);
 
-	axis[0].setLabel(new Label(i18n("x-Axis")));
-	axis[1].setLabel(new Label(i18n("y-Axis")));
-	axis[2].setLabel(new Label(i18n("z-Axis")));
-	axis[3].setLabel(new Label(i18n("x2-Axis")));
-	axis[4].setLabel(new Label(i18n("y2-Axis")));
-	axis[5].setLabel(new Label(i18n("z2-Axis")));
-	axis[6].setLabel(new Label(i18n("x3-Axis")));
-	axis[7].setLabel(new Label(i18n("y3-Axis")));
-	axis[8].setLabel(new Label(i18n("z3-Axis")));
-	axis[9].setLabel(new Label(i18n("x4-Axis")));
-	axis[10].setLabel(new Label(i18n("y4-Axis")));
-	axis[11].setLabel(new Label(i18n("z4-Axis")));
+	// set default axis settings for all axes
+	for(int i=0;i<12;i++)
+		readAxisSettings(&axis[i],P3D,i);
+
+	axis[0].setLabel(new Label(i18n("x-Axis"),font));
+	axis[1].setLabel(new Label(i18n("y-Axis"),font));
+	axis[2].setLabel(new Label(i18n("z-Axis"),font));
+	axis[3].setLabel(new Label(i18n("x2-Axis"),font));
+	axis[4].setLabel(new Label(i18n("y2-Axis"),font));
+	axis[5].setLabel(new Label(i18n("z2-Axis"),font));
+	axis[6].setLabel(new Label(i18n("x3-Axis"),font));
+	axis[7].setLabel(new Label(i18n("y3-Axis"),font));
+	axis[8].setLabel(new Label(i18n("z3-Axis"),font));
+	axis[9].setLabel(new Label(i18n("x4-Axis"),font));
+	axis[10].setLabel(new Label(i18n("y4-Axis"),font));
+	axis[11].setLabel(new Label(i18n("z4-Axis"),font));
 
 	// grid & border
+	font.setPointSize((int)(0.7*font.pointSize()));	// for tic label
+
 	for (int i=0;i<12;i++) {
-		borderenabled[i] = TRUE;
-		axis[i].enable(1);
+		axis[i].setTickLabelFont(font);
 	}
-	for (int i=3;i<12;i++)
-		axis[i].enable(0);
-	for (int i=0;i<24;i++)
-		gridenabled[i] = FALSE;
 }
 
 QStringList Plot3D::Info() {
+	kdDebug()<<"Plot3D::Info()"<<endl;
 	QStringList s;
 	s<<"3D";
 	s<<QString::number(position.X())+QString(" , ")+QString::number(position.Y());
@@ -54,6 +58,7 @@ QStringList Plot3D::Info() {
 }
 
 void Plot3D::setBorder(int item, bool on) {
+	kdDebug()<<"Plot3D::setBorder() : item="<<item<<endl;
 	const int unit = 5, numunit = 40, numunit2 = 20;
 	int w = worksheet->width(), h = worksheet->height();
 
@@ -64,51 +69,51 @@ void Plot3D::setBorder(int item, bool on) {
 
 	if(item == 3) {
 		if (on) {
-			if (axis[3].label()->title().length() > 0) ymax -= axis[3].label()->font().pointSize();
-			if (axis[3].MajorTicsEnabled())   ymax -= unit+numunit2;
-			if (axis[3].MinorTicsEnabled())   ymax -= unit;
+			if (axis[3].getLabel()->Title().length() > 0) ymax -= axis[3].getLabel()->Font().pointSize();
+			if (axis[3].MajorTicksEnabled())   ymax -= unit+numunit2;
+			if (axis[3].MinorTicksEnabled())   ymax -= unit;
 		}
 		else {
-			if (axis[3].label()->title().length() > 0) ymax += axis[3].label()->font().pointSize();
-			if (axis[3].MajorTicsEnabled())   ymax += unit+numunit2;
-			if (axis[3].MinorTicsEnabled())   ymax += unit;
+			if (axis[3].getLabel()->Title().length() > 0) ymax += axis[3].getLabel()->Font().pointSize();
+			if (axis[3].MajorTicksEnabled())   ymax += unit+numunit2;
+			if (axis[3].MinorTicksEnabled())   ymax += unit;
 
 		}
 	}
 	if(item == 5) {
 		if (on) {
-			if (axis[5].label()->title().length() > 0) xmin += axis[5].label()->font().pointSize();
-			if (axis[5].MajorTicsEnabled())   xmin += unit+numunit;
-			if (axis[5].MinorTicsEnabled())   xmin += unit;
+			if (axis[5].getLabel()->Title().length() > 0) xmin += axis[5].getLabel()->Font().pointSize();
+			if (axis[5].MajorTicksEnabled())   xmin += unit+numunit;
+			if (axis[5].MinorTicksEnabled())   xmin += unit;
 		}
 		else {
-			if (axis[5].label()->title().length() > 0) xmin -= axis[5].label()->font().pointSize();
-			if (axis[5].MajorTicsEnabled())   xmin -= unit+numunit;
-			if (axis[5].MinorTicsEnabled())   xmin -= unit;
+			if (axis[5].getLabel()->Title().length() > 0) xmin -= axis[5].getLabel()->Font().pointSize();
+			if (axis[5].MajorTicksEnabled())   xmin -= unit+numunit;
+			if (axis[5].MinorTicksEnabled())   xmin -= unit;
 		}
 	}
 	if(item == 9) {
 		if (on) {
-			if (axis[9].label()->title().length() > 0) ymin += axis[9].label()->font().pointSize();
-			if (axis[9].MajorTicsEnabled())   ymin += unit+numunit2;
-			if (axis[9].MinorTicsEnabled())   ymin += unit;
+			if (axis[9].getLabel()->Title().length() > 0) ymin += axis[9].getLabel()->Font().pointSize();
+			if (axis[9].MajorTicksEnabled())   ymin += unit+numunit2;
+			if (axis[9].MinorTicksEnabled())   ymin += unit;
 		}
 		else {
-			if (axis[9].label()->title().length() > 0) ymin += axis[9].label()->font().pointSize();
-			if (axis[9].MajorTicsEnabled())   ymin += unit+numunit2;
-			if (axis[9].MinorTicsEnabled())   ymin += unit;
+			if (axis[9].getLabel()->Title().length() > 0) ymin += axis[9].getLabel()->Font().pointSize();
+			if (axis[9].MajorTicksEnabled())   ymin += unit+numunit2;
+			if (axis[9].MinorTicksEnabled())   ymin += unit;
 		}
 	}
 	if(item == 11) {
 		if (on) {
-			if (axis[11].label()->title().length() > 0) xmax -= axis[11].label()->font().pointSize();
-			if (axis[11].MajorTicsEnabled())   xmax -= unit+numunit;
-			if (axis[11].MinorTicsEnabled())   xmax -= unit;
+			if (axis[11].getLabel()->Title().length() > 0) xmax -= axis[11].getLabel()->Font().pointSize();
+			if (axis[11].MajorTicksEnabled())   xmax -= unit+numunit;
+			if (axis[11].MinorTicksEnabled())   xmax -= unit;
 		}
 		else {
-			if (axis[11].label()->title().length() > 0) xmax += axis[11].label()->font().pointSize();
-			if (axis[11].MajorTicsEnabled())   xmax += unit+numunit;
-			if (axis[11].MinorTicsEnabled())   xmax += unit;
+			if (axis[11].getLabel()->Title().length() > 0) xmax += axis[11].getLabel()->Font().pointSize();
+			if (axis[11].MajorTicksEnabled())   xmax += unit+numunit;
+			if (axis[11].MinorTicksEnabled())   xmax += unit;
 		}
 	}
 
@@ -119,9 +124,13 @@ void Plot3D::setBorder(int item, bool on) {
 }
 
 void Plot3D::draw(QPainter *p,int w, int h) {
-	//int w = worksheet->width(), h = worksheet->height();
-
 	kdDebug()<<"Plot3D::draw() w/h : "<<w<<' '<<h<<endl;
+	
+	if(aspect_enabled) {	// set aspect ratio to 1
+		int wsize = (int) fmin(w,h);
+		w=h=wsize;
+	}	
+
 	int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	int xmax = (int)(w*(size.X()*p2.X()+position.X()));
 	int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
@@ -142,7 +151,6 @@ void Plot3D::draw(QPainter *p,int w, int h) {
 
 		// graph background color
 		p->setBrush(gbgcolor);
-		//TEST : p->setBrush(Qt::green);
 		p->setPen(Qt::NoPen);
 	}
 
@@ -152,12 +160,13 @@ void Plot3D::draw(QPainter *p,int w, int h) {
 		(xmax+xmin)/2,ymin-(ymax-ymin)/2,xmin,ymin);
 	p->drawPolygon(a);
 
-        // TODO : draw baseline here (before every axis ?) -> see Plot2D.cc
+        // TODO : draw y baseline here (before every axis ?) -> see Plot2D.cc
+        // TODO : draw x baseline here (before every axis ?) -> see Plot2D.cc
 
 	// TODO
 	kdDebug()<<"PLOT3D : title->draw() pos:"<<position.X()<<' '<<position.Y()<<endl;
 	kdDebug()<<" 			size:"<<size.X()<<' '<<size.Y()<<endl;
-	title->draw(p,position,size,w,h,0);
+	title->draw(worksheet,p,position,size,w,h,0);
 
 	drawAxes(p,w,h,0);	// all axes & borders
 	drawBorder(p,w,h,0);
@@ -167,11 +176,15 @@ void Plot3D::draw(QPainter *p,int w, int h) {
 	drawAxes(p,w,h,1);	// only front axes & borders
 	drawBorder(p,w,h,1);
 
-	if(legend.enabled())
+	if(legend.Enabled())
 		legend.draw(p,type,graphlist,position,size,w,h);
+
+	p->setPen(Qt::NoPen);
 }
 
 void Plot3D::drawBorder(QPainter *p,int w, int h,bool hide) {
+	kdDebug()<<"Plot3D::drawBorder()"<<endl;
+	// TODO : borderwidth
 	int start=0;
 	if (hide) start=3;
 
@@ -194,8 +207,8 @@ void Plot3D::drawBorder(QPainter *p,int w, int h,bool hide) {
 		ymin,(3*ymin-ymax)/2,ymax,(3*ymin-ymax)/2,(3*ymin-ymax)/2,(ymin+ymax)/2};
 
 	for (int i=start;i<12;i++) {
-		if (borderenabled[i]) {
-			p->setPen(axis[i].BorderColor());
+		if (axis[i].BorderEnabled()) {
+			p->setPen(QPen(axis[i].BorderColor(),axis[i].borderWidth()));
 			p->drawLine(x1[i],y1[i],x2[i],y2[i]);
 		}
 	}
@@ -215,16 +228,16 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 	kdDebug()<<"xmin/xmax ymin/ymax : "<<xmin<<'/'<<xmax<<' '<<ymin<<'/'<<ymax<<endl;
 	kdDebug()<<"width/height : "<<w<<'/'<<h<<endl;
 
-	for (unsigned int i=0; i < graphlist->getNumber() ; i++) {
+	for (unsigned int i=0; i < graphlist->Number() ; i++) {
 		kdDebug()<<"draw Graph "<<i+1<<endl;
-		if(graphlist->getGraph(i)->isShown() == FALSE)
+		if(graphlist->getGraph(i)->isShown() == false)
 			continue;
 		
 		double oldx=0, oldy=0;
 		double oldlinex=0, oldliney=0;
 		int N, NY=0, NX=0;
-		Style style;
-		Symbol symbol;
+		Style *style=0;
+		Symbol *symbol=0;
 		GRAPHType s = graphlist->getStruct(i);
 		Graph *graph=graphlist->getGraph(i);
 		Point3D *d=0;
@@ -261,12 +274,25 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 		else
 			N=NX*NY;
 
-		int type = style.Type();
+		int type = style->Type();
 
 		double *linex = new double[NX], *liney = new double[NX];	// NX is ok here
 		for (int k=NY-1; k>=0;k--) {
+			if(worksheet->getMainWin()->speedMode()) {
+				int mod = (int) (NY/sqrt((double) worksheet->getMainWin()->speedModeValue()));
+				if(mod==0) mod=1;
+				if(k%mod != 0) continue;	// speed mode
+			}
 			for(int j=NX-1 ;j>=0;j--) {
 				int index = j+k*NX;
+				if (d[index].Masked())
+					continue;
+				
+				if(worksheet->getMainWin()->speedMode()) {
+					int mod = (int) (NX/sqrt((double) worksheet->getMainWin()->speedModeValue()));
+					if(mod==0) mod=1;
+					if(j%mod != 0) continue;	// speed mode
+				}
 				// TODO : scales (log10,log2,ln,sqrt)
 				double x = xmin + (d[index].X() - actrange[0].rMin()) *
 					(xmax-xmin)/(actrange[0].rMax() - actrange[0].rMin())
@@ -279,22 +305,22 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 					- (d[index].Z()-actrange[2].rMin()) * (ymax-ymin)/(actrange[2].rMax()
 					  - actrange[2].rMin());
 
-				int xlen = (xmax-xmin)/(NX-1);
+				int xlen = xmax-xmin;
 				int ylen = ymax-ymin;
-				if (NY>1)
-					ylen = (ymax-ymin)/(NY-1);
+				if (NX>1) xlen = (xmax-xmin)/(NX-1);
+				if (NY>1) ylen = (ymax-ymin)/(NY-1);
 
 				int dropy = (int)(y+(d[index].Z()-actrange[2].rMin()) *
 						(ymax-ymin)/(actrange[2].rMax() - actrange[2].rMin()));
 
 				if (x >= xmin-1 && x <= xmax+(xmax-xmin)/2+1
 						&& y >= ymin-(ymax-ymin)/2-1 && y <= ymax+1) {
-					QPen pen( style.Color(), style.Width(),(Qt::PenStyle) style.PenStyle() );
+					QPen pen( style->Color(), style->Width(),(Qt::PenStyle) style->PenStyle() );
 					p->setPen(pen);
 
-					if (style.isFilled()) {
+					if (style->isFilled()) {
 						QPointArray a;
-						p->setBrush(style.FillColor());
+						p->setBrush(style->FillColor());
 
 						if (type == 0) {
 //							if (k>0 && j<NX-1) {
@@ -354,7 +380,7 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 					if (type == 4)
 						p->drawLine((int)x,(int)y,(int)x,(int)dropy);
 
-					symbol.draw(p,(int)x,(int)y);
+					symbol->draw(p,(int)x,(int)y);
 					graph->getAnnotateValues().draw(p,(int)x,(int)y,d[index].X(),d[index].Y(),d[index].Z());
 				}
 				oldx = x;oldy = y;
@@ -369,9 +395,9 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 
 //! draw the axes. hide=1 : only front axes (others hidden by curves)
 void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
+	kdDebug()<<"Plot3D::drawAxes()"<<endl;
 	const int unit = 5, gap = 10, numunit = 40, numunit2 = 20;
 
-	kdDebug()<<"Plot3D::drawAxes()"<<endl;
 	int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	int xmax = (int)(w*(size.X()*p2.X()+position.X()));
 	int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
@@ -390,59 +416,60 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 	// axes label
 	// x,x2,x3,x4
 	double xx[4] = {xmax,xmin+(xmax-xmin)/2,xmin+(xmax-xmin)/2,xmax};
-	double yx[4] = {(ymax+ymin)/2+(2*unit+numunit2)*axis[0].MajorTicsEnabled(),
-		ymax+(2*unit+numunit2)*axis[3].MajorTicsEnabled(),ymin-(2*unit+numunit2)*axis[6].MajorTicsEnabled()-3*gap,
-		ymin-(ymax-ymin)/2-(2*unit+numunit2)*axis[9].MajorTicsEnabled()-3*gap};
+	double yx[4] = {(ymax+ymin)/2+(2*unit+numunit2)*axis[0].MajorTicksEnabled(),
+		ymax+(2*unit+numunit2)*axis[3].MajorTicksEnabled(),ymin-(2*unit+numunit2)*axis[6].MajorTicksEnabled()-3*gap,
+		ymin-(ymax-ymin)/2-(2*unit+numunit2)*axis[9].MajorTicksEnabled()-3*gap};
 	for (int i=start;i<4;i++) {
-		Label *label = axis[3*i].label();
+		Label *label = axis[3*i].getLabel();
 		if (label->X()==0)	// default
 			label->setPosition((xx[i]+gap)/(double)w,yx[i]/(double)h);
-		if (axis[3*i].enabled())
-			label->draw(p,position,size,w,h,0);
+		if (axis[3*i].Enabled())
+			label->draw(worksheet,p,position,size,w,h,0);
 	}
 
 	// z,z2,z3,z4
-	double xz[4] = {xmax-2*(xmax-xmin)/3-2*gap+axis[2].label()->font().pointSize()-gap,
-			gap+axis[5].label()->font().pointSize()-gap, xmax+(2*unit+numunit)*axis[8].MajorTicsEnabled(),
-			xmax+(xmax-xmin)/2+(2*unit+numunit)*axis[11].MajorTicsEnabled()};
+	double xz[4] = {xmax-2*(xmax-xmin)/3-2*gap+axis[2].getLabel()->Font().pointSize()-gap,
+			gap+axis[5].getLabel()->Font().pointSize()-gap, xmax+(2*unit+numunit)*axis[8].MajorTicksEnabled(),
+			xmax+(xmax-xmin)/2+(2*unit+numunit)*axis[11].MajorTicksEnabled()};
 	double yz[4] = {ymin,ymin+(ymax-ymin)/2,ymin+(ymax-ymin)/2,ymin};
 	for (int i=start;i<4;i++) {
-		Label *label = axis[3*i+2].label();
+		Label *label = axis[3*i+2].getLabel();
 		p->save();
 		if (label->X()==0)	// default
 			label->setPosition(xz[i]/(double)w,(yz[i]-gap)/(double)h);
-		if (axis[3*i+2].enabled())
-			label->draw(p,position,size,w,h,270);
+		if (axis[3*i+2].Enabled())
+			label->draw(worksheet,p,position,size,w,h,270);
 		p->restore();
 	}
 
 	// y,y,2,y3,y4
 	double dx = (xmax-xmin)/2, dy = (ymax-ymin)/2;
 	double phi = 180.0/M_PI*atan(dy/dx);
-	double xy[4] = {xmin+(xmax+xmin)/4-(2*unit+numunit)*axis[1].MajorTicsEnabled(),
-		xmax+(xmax+xmin)/4+(2*unit+numunit)*axis[4].MajorTicsEnabled()-4*gap,
-		xmax+(xmax+xmin)/4+(2*unit+numunit)*axis[7].MajorTicsEnabled()-4*gap,
-		xmin+(xmax+xmin)/4-(2*unit+numunit)*axis[10].MajorTicsEnabled()
+	double xy[4] = {xmin+(xmax+xmin)/4-(2*unit+numunit)*axis[1].MajorTicksEnabled(),
+		xmax+(xmax+xmin)/4+(2*unit+numunit)*axis[4].MajorTicksEnabled()-4*gap,
+		xmax+(xmax+xmin)/4+(2*unit+numunit)*axis[7].MajorTicksEnabled()-4*gap,
+		xmin+(xmax+xmin)/4-(2*unit+numunit)*axis[10].MajorTicksEnabled()
 		};
 	double yy[4] = {ymax-(ymax-ymin)/4-4*gap,ymax-(ymax-ymin)/4+2*gap,
 		ymin-(ymax-ymin)/4+2*gap,ymin-(ymax-ymin)/4-4*gap };
 	for (int i=start;i<4;i++) {
-		Label *label = axis[3*i+1].label();
+		Label *label = axis[3*i+1].getLabel();
 		p->save();
 		if (label->X()==0)	// default
 			label->setPosition((xy[i]-2*gap)/(double)w,yy[i]/(double)h);
-		if (axis[3*i+1].enabled())
-			label->draw(p,position,size,w,h,360-phi);
+		if (axis[3*i+1].Enabled())
+			label->draw(worksheet,p,position,size,w,h,360-phi);
 		p->restore();
 	}
 
-	// Tics and Grid
+	// Ticks and Grid
+	kdDebug()<<"Drawing Ticks and Grid"<<endl;
 	// TODO : scales (log10,log2,ln,sqrt)
 	// x,x2,x3,x4
 	for (int k=start;k<4;k++) {
 		int xi[4]={(xmin+xmax)/2,xmin,xmin,(xmin+xmax)/2};
 		int yi1[4], yi2[4], ykna[4], yknb[4];
-		switch (axis[3*k].TicsPos()) {	// major/minor tics 
+		switch (axis[3*k].TickPos()) {	// major/minor tics 
 		case 0:
 			yi1[0]=ymax-(ymax-ymin)/2+10; yi1[1]=ymax; yi1[2]=ymin-10; yi1[3]=ymin-(ymax-ymin)/2-10;
 			yi2[0]=ymax-(ymax-ymin)/2; yi2[1]=ymax+10; yi2[2]=ymin; yi2[3]=ymin-(ymax-ymin)/2;
@@ -468,17 +495,19 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 		int yib[4]={ymax-(ymax-ymin)/2,ymax,ymax,ymin};
 		int yina[4]={ymin-(ymax-ymin)/2,ymax-(ymax-ymin)/2,ymin,ymin-(ymax-ymin)/2};
 		int yinb[4]={ymax-(ymax-ymin)/2,ymax,ymax,ymin};
-		if (axis[3*k].MajorTicsEnabled() && axis[3*k].enabled()) {
+		if (axis[3*k].MajorTicksEnabled() && axis[3*k].Enabled()) {
 			double min = actrange[0].rMin(), max = actrange[0].rMax();
 			TScale scale = axis[k].Scale();
 			int t=-1;
 			switch (scale) {
-			case LINEAR: t = axis[3*k].MajorTics(); break;
+			case LINEAR: case SX2: t = (int) axis[3*k].MajorTicks(); break;
 			case LOG10: t = (int) log10(max/min)+2; break;
 			case LOG2: t = (int) log2(max/min)+2; break;
 			case LN: t = (int) log(max/min)+2; break;
 			case SQRT: t = (int) (pow(max,2)-pow(min,2))+1; break;
 			}
+			if(t==-1)
+				t=autoTicks(min,max);
 			if(t==0) t=-1;
 
 			for (int i=0;i <= t;i++) {
@@ -510,27 +539,29 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					x1 = xi[k]+(int)((sqrt(min*min+i)-min)/(max-min)*(xmax-xmin));
 					x2 = xi[k]+(int)((sqrt(min*min+i+1)-min)/(max-min)*(xmax-xmin));
 					} break;
+				default: break;
 				}
 
 				int xia[4]={x1,x1+(xmax-xmin)/2,x1,x1};
 				int xib[4]={x1,x1,x1,x1-(xmax-xmin)/2};
 
-				// major tics
-				if(axis[3*k].TicsPos()!=3) {
-					p->setPen(axis[3*k].TicsColor());
+				// major ticks
+				if(axis[3*k].TickPos()!=3) {
+					kdDebug()<<"DRAWING MAJOR TICKS"<<endl;
+					p->setPen(QPen(axis[3*k].TickColor(),axis[3*k].majorTickWidth()));
 					p->drawLine(x1,yi1[k],x1,yi2[k]);
 				}
 
-				if (gridenabled[6*k]) {
-					p->setPen(Qt::DashLine);
-					p->setPen(axis[3*k].GridColor());
+				if (axis[3*k].MajorGridEnabled()) {
+					p->setPen(QPen(axis[3*k].majorGridColor(),
+						axis[3*k].majorGridWidth(),axis[3*k].MajorGridType()));
 					p->drawLine(xia[k],yia[k],xib[k],yib[k]);
 					p->setPen(Qt::SolidLine);
 				}
-				if (graphlist->getNumber() > 0) {
-					QColor c = axis[3*k].TicsLabelColor();
-					QFont f = axis[3*k].TicsFont();
-					int atlf = axis[3*k].TicsLabelFormat();
+				if (graphlist->Number() > 0) {
+					QColor c = axis[3*k].TickLabelColor();
+					QFont f = axis[3*k].TickLabelFont();
+					int atlf = axis[3*k].TickLabelFormat();
 
 					double dx = max-min;
 					double value=0;
@@ -540,26 +571,27 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 						case LOG2: value = pow(2,ceil(log2(min)))*pow(2.0,i-1); break;
 						case LN: value = pow(M_E,ceil(log(min)))*pow(M_E,i-1); break;
 						case SQRT: value = min + i*dx/t; break;
+						default: break;
 					}
 
 					// scale and shift value
 					value = value*axis[3*k].Scaling()+axis[3*k].Shift();
 
-					QString label = TicLabel(3*k,atlf,axis[3*k].TicsLabelPrecision(), 
+					QString label = TicLabel(atlf,axis[3*k].TickLabelPrecision(), 
 						axis[3*k].DateTimeFormat(),value);
 						
 					// apply prefix & suffix
-					label.prepend(axis[3*k].TicsLabelPrefix());
-					label.append(axis[3*k].TicsLabelSuffix());
+					label.prepend(axis[3*k].TickLabelPrefix());
+					label.append(axis[3*k].TickLabelSuffix());
 
 					// draw tic label
 					QFontMetrics fm(f);
 					p->save();
-					int tlg = axis[3*k].TicsLabelGap();
+					int tlg = axis[3*k].TickLabelPosition();
 					int yilb[4]={ymax-(ymax-ymin)/2+fm.ascent()+tlg,ymax+fm.ascent()+tlg,
 						ymin-tlg,ymin-(ymax-ymin)/2-tlg};
 					p->translate(x1,yilb[k]);
-					p->rotate(axis[3*k].TicsLabelRotation());
+					p->rotate(axis[3*k].TickLabelRotation());
 					if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
 						p->setPen(c);
 						f.setPointSize((int)(f.pointSize()*size.X()));	// resize tic label
@@ -575,18 +607,18 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					}
 					p->restore();
 				}
-				if (axis[3*k].MinorTicsEnabled() && i != t ) {
-					for (int j=1;j <= axis[3*k].MinorTics()+1;j++) {
-						int x = x1+j*(x2-x1)/(axis[3*k].MinorTics()+1);
+				if (axis[3*k].MinorTicksEnabled() && i != t ) {
+					for (int j=1;j <= axis[3*k].MinorTicks()+1;j++) {
+						int x = x1+j*(x2-x1)/(axis[3*k].MinorTicks()+1);
 						int xina[4]={x,x+(xmax-xmin)/2,x,x};
 						int xinb[4]={x,x,x,x-(xmax-xmin)/2};
-						if(axis[3*k].TicsPos()!=3) {
-							p->setPen(axis[3*k].TicsColor());
+						if(axis[3*k].TickPos()!=3) {
+							p->setPen(QPen(axis[3*k].TickColor(),axis[3*k].minorTickWidth()));
 							p->drawLine(x,ykna[k],x,yknb[k]);
 						}
-						if (gridenabled[6*k+1]) {
-							p->setPen(Qt::DotLine);
-							p->setPen(axis[3*k].GridColor());
+						if (axis[3*k].MinorGridEnabled() && j != axis[3*k].MinorTicks()+1 ) {
+							p->setPen(QPen(axis[3*k].minorGridColor(),
+								axis[3*k].minorGridWidth(),axis[3*k].MinorGridType()));
 							p->drawLine(xina[k],yina[k],xinb[k],yinb[k]);
 							p->setPen(Qt::SolidLine);
 						}
@@ -600,7 +632,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 	for (int k=start;k<4;k++) {
 		int yi[4]={ymin-(ymax-ymin)/2,ymin,ymin,ymin-(ymax-ymin)/2};
 		int xi1[4], xi2[4], xkna[4], xknb[4];
-		switch (axis[3*k+2].TicsPos()) {
+		switch (axis[3*k+2].TickPos()) {
 		case 0:
 			//major tics
 			xi1[0]=(xmax+xmin)/2; xi1[1]=xmin-10; xi1[2]=xmax; xi1[3]=xmax+(xmax-xmin)/2;
@@ -631,17 +663,20 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 		int xina[4]={xmin,xmin,xmax,(xmax+xmin)/2};
 		int xinb[4]={(xmax+xmin)/2,xmax,xmax+(xmax-xmin)/2,xmax+(xmax-xmin)/2};
 		
-		if (axis[3*k+2].MajorTicsEnabled() && axis[3*k+2].enabled()) {
+		if (axis[3*k+2].MajorTicksEnabled() && axis[3*k+2].Enabled()) {
 			double min = actrange[2].rMin(), max = actrange[2].rMax();
 			TScale scale = axis[k].Scale();
 			int t=-1;
 			switch (scale) {
-			case LINEAR: t = axis[3*k+2].MajorTics(); break;
+			case LINEAR: t = (int) axis[3*k+2].MajorTicks(); break;
 			case LOG10: t = (int) log10(max/min)+2; break;
 			case LOG2: t = (int) log2(max/min)+2; break;
 			case LN: t = (int) log(max/min)+2; break;
 			case SQRT: t = (int) (pow(max,2)-pow(min,2))+1; break;
+			default: break;
 			}
+			if(t==-1)
+				t=autoTicks(min,max);
 			if(t==0) t=-1;
 			
 			for (int i=0;i <= t;i++) {
@@ -650,22 +685,22 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 				int y2 = yi[k]+(i+1)*(ymax-ymin)/t;
 				int yia[4] = {ymin+i*(ymax-ymin)/t,y1,y1+(ymin-ymax)/2,y1};
 			
-				if (axis[3*k+2].TicsPos()!=3) {
-					p->setPen(axis[3*k+2].TicsColor());
+				if (axis[3*k+2].TickPos()!=3) {
+					p->setPen(QPen(axis[3*k+2].TickColor(),axis[3*k+2].majorTickWidth()));
 					p->drawLine(xi1[k],y1,xi2[k],y1);
 				}
 				
-				if (gridenabled[6*k+4]) {
-					p->setPen(Qt::DashLine);
-					p->setPen(axis[3*k+2].GridColor());
+				if (axis[3*k+2].MajorGridEnabled()) {
+					p->setPen(QPen(axis[3*k+2].majorGridColor(),
+						axis[3*k+2].majorGridWidth(),axis[3*k+2].MajorGridType()));
 					p->drawLine(xia[k],yia[k],xib[k],y1);
 					p->setPen(Qt::SolidLine);
 				}
-				if (graphlist->getNumber() > 0) {
-					QColor c = axis[3*k+2].TicsLabelColor();
-					QFont f = axis[3*k+2].TicsFont();
+				if (graphlist->Number() > 0) {
+					QColor c = axis[3*k+2].TickLabelColor();
+					QFont f = axis[3*k+2].TickLabelFont();
 					double dz = max-min;
-					int atlf = axis[3*k+2].TicsLabelFormat();
+					int atlf = axis[3*k+2].TickLabelFormat();
 	
 					double value=0;
 					switch(scale) {
@@ -674,26 +709,27 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 						case LOG2: value = pow(2,ceil(log2(min)))*pow(2.0,i-1); break;
 						case LN: value = pow(M_E,ceil(log(min)))*pow(M_E,i-1); break;
 						case SQRT: value = min + (t-i)*dz/t; break;
+						default: break;
 					}
 					// scale and shift value
 					value = value*axis[3*k+2].Scaling()+axis[3*k+2].Shift();
 	
-					QString label = TicLabel(3*k+2,atlf,axis[3*k+2].TicsLabelPrecision(),
+					QString label = TicLabel(atlf,axis[3*k+2].TickLabelPrecision(),
 							axis[3*k+2].DateTimeFormat(),value);
 
 					// apply prefix & suffix
-					label.prepend(axis[3*k+2].TicsLabelPrefix());
-					label.append(axis[3*k+2].TicsLabelSuffix());
+					label.prepend(axis[3*k+2].TickLabelPrefix());
+					label.append(axis[3*k+2].TickLabelSuffix());
 
 					// draw tic label
 					QFontMetrics fm(f);
 					p->save();
-					int tlg = axis[3*k+2].TicsLabelGap();
+					int tlg = axis[3*k+2].TickLabelPosition();
 					if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
 						int xk[4]={(xmax+xmin)/2-fm.width(label)/2-tlg,xmin-fm.width(label)/2-tlg,
 							xmax+tlg,xmax+(xmax-xmin)/2+tlg};
 						p->translate(xk[k],y1);
-						p->rotate(axis[3*k+2].TicsLabelRotation());
+						p->rotate(axis[3*k+2].TickLabelRotation());
 						p->setPen(c);
 						f.setPointSize((int)(f.pointSize()*size.X()));	// resize tic label
 						p->setFont(f);
@@ -705,25 +741,25 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 						int xk[4]={(xmax+xmin)/2-richtext->width()/2-tlg,xmin-richtext->width()-tlg,
 							xmax+tlg,xmax+(xmax-xmin)/2+tlg};
 						p->translate(xk[k],y1);
-						p->rotate(axis[3*k+2].TicsLabelRotation());
+						p->rotate(axis[3*k+2].TickLabelRotation());
 						QColorGroup cg;
 						cg.setColor(QColorGroup::Text,c);
 						richtext->draw(p,-richtext->width()/2, -fm.ascent()/2,QRect(),cg);
 					}
 					p->restore();
 				}
-				if (axis[3*k+2].MinorTicsEnabled() && i != t ) {
-					for (int j=1;j <= axis[3*k+2].MinorTics()+1;j++) {
-						int y = y1+j*(y2-y1)/(axis[3*k+2].MinorTics()+1);
+				if (axis[3*k+2].MinorTicksEnabled() && i != t ) {
+					for (int j=1;j <= axis[3*k+2].MinorTicks()+1;j++) {
+						int y = y1+j*(y2-y1)/(axis[3*k+2].MinorTicks()+1);
 						int yina[4]={y+(ymax-ymin)/2,y,y,y};
 						int yinb[4]={y,y,y+(ymin-ymax)/2,y};
-						if(axis[3*k+2].TicsPos()!=3) {
-							p->setPen(axis[3*k+2].TicsColor());
+						if(axis[3*k+2].TickPos()!=3) {
+							p->setPen(QPen(axis[3*k+2].TickColor(),axis[3*k+2].minorTickWidth()));
 							p->drawLine(xkna[k],y,xknb[k],y);
 						}
-						if (gridenabled[6*k+5]) {
-							p->setPen(Qt::DotLine);
-							p->setPen(axis[3*k+2].GridColor());
+						if (axis[3*k+2].MinorGridEnabled() && j != axis[3*k+2].MinorTicks()+1 ) {
+							p->setPen(QPen(axis[3*k+2].minorGridColor(),
+								axis[3*k+2].minorGridWidth(),axis[3*k+2].MinorGridType()));
 							p->drawLine(xina[k],yina[k],xinb[k],yinb[k]);
 							p->setPen(Qt::SolidLine);
 						}
@@ -737,17 +773,20 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 	for (int k=start;k<4;k++) {
 		int xi[4]={xmin,xmax,xmax,xmin};
 		int yi[4]={ymax,ymax,ymin,ymin};
-		if (axis[3*k+1].MajorTicsEnabled() && axis[3*k+1].enabled()) { 		// y
+		if (axis[3*k+1].MajorTicksEnabled() && axis[3*k+1].Enabled()) { 		// y
 			double min = actrange[1].rMin(), max = actrange[1].rMax();
 			TScale scale = axis[k].Scale();
 			int t=-1;
 			switch (scale) {
-			case LINEAR: t = axis[3*k+1].MajorTics(); break;
+			case LINEAR: t =(int) axis[3*k+1].MajorTicks(); break;
 			case LOG10: t = (int) log10(max/min)+2; break;
 			case LOG2: t = (int) log2(max/min)+2; break;
 			case LN: t = (int) log(max/min)+2; break;
 			case SQRT: t = (int) (pow(max,2)-pow(min,2))+1; break;
+			default: break;
 			}
+			if(t==-1)
+				t=autoTicks(min,max);
 			if (t==0) t=-1;
 			
 			for (int i=0;i <= t;i++) {
@@ -758,7 +797,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 				int x2 = xi[k]+(i+1)*(xmax-xmin)/(2*t);
 
 				int xi1[4],xi2[4];
-				switch(axis[3*k+1].TicsPos()) {
+				switch(axis[3*k+1].TickPos()) {
 				case 0:
 					xi1[0]=xi1[1]=xi1[2]=xi1[3]=x1;
 					xi2[0]=xi2[3]=x1-10;xi2[1]=xi2[2]=x1+10;
@@ -776,45 +815,45 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 				int xib[4]={x1+xmax-xmin,x1,x1,x1};
 				int yib[4]={y1,y1-ymax+ymin,y1,y1+ymax-ymin};
 				
-				if (axis[3*k+1].TicsPos()!=3) {
-					p->setPen(axis[3*k+1].TicsColor());
+				if (axis[3*k+1].TickPos()!=3) {
+					p->setPen(QPen(axis[3*k+1].TickColor(),axis[3*k+1].majorTickWidth()));
 					p->drawLine(xi1[k],y1,xi2[k],y1);
 				}
 				
-				if (gridenabled[6*k+2]) {
-					p->setPen(Qt::DashLine);
-					p->setPen(axis[3*k+1].GridColor());
+				if (axis[3*k+1].MajorGridEnabled()) {
+					p->setPen(QPen(axis[3*k+1].majorGridColor(),
+						axis[3*k+1].majorGridWidth(),axis[3*k+1].MajorGridType()));
 					p->drawLine(xia[k],y1,xib[k],yib[k]);
 					p->setPen(Qt::SolidLine);
 				}
-				if (graphlist->getNumber() > 0) {
-					QColor c = axis[3*k+1].TicsLabelColor();
-					QFont f = axis[3*k+1].TicsFont();
+				if (graphlist->Number() > 0) {
+					QColor c = axis[3*k+1].TickLabelColor();
+					QFont f = axis[3*k+1].TickLabelFont();
 					double dy = max-min;
 					int yy[4]={ymax,ymax,ymin,ymin};
 					// TODO : use scale (see x)
 					// TODO : fix rounding bug
 					double value = min+2*dy*(yy[k]-y1)/(ymax-ymin);
-					int atlf = axis[3*k+1].TicsLabelFormat();
+					int atlf = axis[3*k+1].TickLabelFormat();
 
 					// scale and shift value
 					value = value*axis[3*k+1].Scaling()+axis[3*k+1].Shift();
 
-					QString label = TicLabel(3*k+1,atlf,axis[3*k+1].TicsLabelPrecision(),
+					QString label = TicLabel(atlf,axis[3*k+1].TickLabelPrecision(),
 							axis[3*k+1].DateTimeFormat(),value);
 
 					// apply prefix & suffix
-					label.prepend(axis[3*k+1].TicsLabelPrefix());
-					label.append(axis[3*k+1].TicsLabelSuffix());
+					label.prepend(axis[3*k+1].TickLabelPrefix());
+					label.append(axis[3*k+1].TickLabelSuffix());
 
 					// draw tic label
 					QFontMetrics fm(f);
 					p->save();
-					int tlg = axis[3*k+1].TicsLabelGap();
+					int tlg = axis[3*k+1].TickLabelPosition();
 					if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
 						int xilb[4]={x1-fm.width(label)/2-tlg,x1+tlg,x1+tlg,x1-fm.width(label)/2-tlg};
 						p->translate(xilb[k],y1);
-						p->rotate(axis[3*k+1].TicsLabelRotation());
+						p->rotate(axis[3*k+1].TickLabelRotation());
 						p->setPen(c);
 						f.setPointSize((int)(f.pointSize()*size.X()));	// resize tic label
 						p->setFont(f);
@@ -825,24 +864,24 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 						QSimpleRichText *richtext = new QSimpleRichText(label,f);
 						int xilb[4]={x1-richtext->width()/2-tlg,x1+tlg,x1+tlg,x1-richtext->width()/2-tlg};
 						p->translate(xilb[k],y1);
-						p->rotate(axis[3*k+1].TicsLabelRotation());
+						p->rotate(axis[3*k+1].TickLabelRotation());
 						QColorGroup cg;
 						cg.setColor(QColorGroup::Text,c);
 						richtext->draw(p,-richtext->width()/2, -fm.ascent()/2,QRect(),cg);
 					}
 					p->restore();
 				}
-				if (axis[3*k+1].MinorTicsEnabled() && i != t ) {
-					for (int j=1;j <= axis[3*k+1].MinorTics()+1;j++) {
-						int y = y1+j*(y2-y1)/(axis[3*k+1].MinorTics()+1);
-						int x = x1+j*(x2-x1)/(axis[3*k+1].MinorTics()+1);
-						p->setPen(axis[3*k+1].TicsColor());
+				if (axis[3*k+1].MinorTicksEnabled() && i != t ) {
+					for (int j=1;j <= axis[3*k+1].MinorTicks()+1;j++) {
+						int y = y1+j*(y2-y1)/(axis[3*k+1].MinorTicks()+1);
+						int x = x1+j*(x2-x1)/(axis[3*k+1].MinorTicks()+1);
+						p->setPen(QPen(axis[3*k+1].TickColor(),axis[3*k+1].minorTickWidth()));
 						int xina[4]={x,x,x-(xmax-xmin),x};
 						int xinb[4]={x+xmax-xmin,x,x,x};
 						int yinb[4]={y,y-ymax+ymin,y,y+ymax-ymin};
 					
 						int xkna[4],xknb[4];
-						switch(axis[3*k+1].TicsPos()) {
+						switch(axis[3*k+1].TickPos()) {
 						case 0:
 							xkna[0]=xkna[1]=xkna[2]=xkna[3]=x;
 							xknb[0]=xknb[3]=x-5;xknb[1]=xknb[2]=x+5;
@@ -857,13 +896,13 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 							break;
 						}
 					
-						if (axis[3*k+1].TicsPos()!=3) {
+						if (axis[3*k+1].TickPos()!=3) {
 							p->drawLine(xkna[k],y,xknb[k],y);
 						}
-						if (gridenabled[6*k+3]) {
-							p->setPen(Qt::DotLine);
-							p->setPen(axis[3*k+1].GridColor());
-							p->drawLine(xina[k],y,xinb[k],yinb[k]);
+						if (axis[3*k+1].MinorGridEnabled() && j != axis[3*k+1].MinorTicks()+1 ) {
+							p->setPen(QPen(axis[3*k+1].minorGridColor(),
+								axis[3*k+1].minorGridWidth(),axis[3*k+1].MinorGridType()));
+ 								p->drawLine(xina[k],y,xinb[k],yinb[k]);
 							p->setPen(Qt::SolidLine);
 						}
 					}
@@ -875,12 +914,26 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 
 void Plot3D::saveAxes(QTextStream *t) {
 	for (int i = 0; i < 12; i++) {
-		saveAxis(t,&axis[i],gridenabled[2*i],borderenabled[i],gridenabled[2*i+1]);
+		saveAxis(t,&axis[i]);
 	}
 }
 
 void Plot3D::openAxes(QTextStream *t, int version) {
 	for(int i = 0;i<12;i++) {
-		openAxis(t,version, &axis[i],&gridenabled[2*i],&borderenabled[i],&gridenabled[2*i+1]);
+		openAxis(t,version, &axis[i]);
 	}
 }
+
+void Plot3D::saveXML(QDomDocument doc,QDomElement plottag) {
+	QDomElement tag;
+
+	for (int i = 0; i < 12; i++) {
+		tag = axis[i].saveXML(doc,i);
+   		plottag.appendChild( tag );
+	}
+}
+
+void Plot3D::openXML(QDomElement e) {
+	if(e.tagName() == "Axis")
+		axis[e.attribute("id").toInt()].openXML(e.firstChild());
+}
