@@ -10,23 +10,21 @@ public:
 	PlotTernary(Worksheet *p);
 	~PlotTernary() {}
 	QStringList Info();
-	Axis *getAxis(int i) { return &axis; }
+	Axis *getAxis(int) { return &axis; }
 	void saveAxes(QTextStream *t);
 	void openAxes(QTextStream *t,int version);
-	void enableGrid(int index,bool b) { gridenabled[index]=b; }
-	bool gridEnabled(int index) { return gridenabled[index]; }
-	void enableBorder(int index,bool b) { }	// TODO
-	bool borderEnabled(int index) { return false; }	// TODO
+	void saveXML(QDomDocument doc, QDomElement plottag);
+	void openXML(QDomElement e);
 	void draw(QPainter* p,int w, int h);
 	void drawCurves(QPainter* p, int w, int h);
 /*	void drawAxes(QPainter* p,bool hide);*/
-	void setBorder(int item, bool on) {}
+	void setBorder(int, bool) {}
+	void setRange(LRange* r,int i) {range[i]=*r;}
+	void setActRange(LRange* r,int i) {actrange[i]=*r;}
 	void setRanges(LRange* r) {range[0]=r[0];range[1]=r[1];}
 	void setActRanges(LRange* r) {actrange[0]=r[0];actrange[1]=r[1];}
 private:
 	Axis axis;					// only one axis (drawn 3 times)
-	bool borderenabled;		// one axis border
-	bool gridenabled[2];		// major, minor
 //	TODO : Label label[3];				// 3 axes label
 };
 
