@@ -9,9 +9,14 @@ public:
 	Point(double a=0, double b=0);
 	void setPoint(double, double);
 	double X() { return x; }
+	void setX(double s) { x=s; }
 	double Y() { return y; }
+	void setY(double s) { y=s; }
+	void setMasked(bool m=true ) { masked = m; }
+	bool Masked() { return masked; }
 protected:
 	double x,y;		
+	bool masked;
 };
 
 #endif //POINT_H
