@@ -9,10 +9,16 @@ public:
 	Point3D( double a=0, double b=0, double c=0);
 	void setPoint( double, double, double);
 	double X() { return x; }
+	void setX(double s) { x=s; }
 	double Y() { return y; }
+	void setY(double s) { y=s; }
 	double Z() { return z; }
+	void setZ(double s) { z=s; }
+	void setMasked(bool m=true ) { masked = m; }
+	bool Masked() { return masked; }
 protected:
 	double x,y,z;		
+	bool masked;
 };
 
 #endif //POINT3D_H
