@@ -5,11 +5,14 @@
 
 #include <qstring.h>
 #include <qdatetime.h>
+#include <qdom.h>
 
 class Project
 {
 public:
 	Project();
+	QDomElement saveXML(QDomDocument doc);
+	void openXML(QDomNode node);
 	QString Filename() { return filename; }
 	void setFilename(QString f) {filename=f;}
 	int Version() {return version; }
