@@ -13,29 +13,50 @@
 
 using namespace std;
 
-TitleDialog::TitleDialog(Worksheet *p, const char *name)
-	: Dialog(p, name)
+TitleDialog::TitleDialog(MainWin *mw, const char *name)
+	: Dialog(mw, name)
 {
+	kdDebug()<<"TitleDialog()"<<endl;
 	setCaption(i18n("Title Settings")+i18n(" : ")+QString(name));
 
 	title = p->getPlot(p->API())->Title();
 
-	rtw = new RichTextWidget((QWidget *)vbox,title,0);
+	if(mw->activeWorksheet() && mw->activeWorksheet()->getPlot(0) &&
+		mw->activeWorksheet()->getPlot(0)->Type() == PQWT3D )
+		rtw = new RichTextWidget((QWidget *)vbox,title,0,1);
+	else
+		rtw = new RichTextWidget((QWidget *)vbox,title,0);
 
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
+	save->setEnabled(false);
 	
 	setMinimumWidth(2*vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
-void TitleDialog::apply_clicked() {
+void TitleDialog::updateDialog() {
+	p = mw->activeWorksheet();
+	
+	if(p != 0) {
+		Plot *plot = p->getPlot(p->API());
+		if(plot != 0) {
+			title = plot->Title();
+			rtw->setLabel(title);
+		}
+	}
+}
+
+int TitleDialog::apply_clicked() {
+	kdDebug()<<"TitleDialog::apply_clicked()"<<endl;
 	
 	title = rtw->label();
 	
-	p->getMainWin()->updateSheetList();
+	mw->updateSheetList();
 	p->updatePixmap();
+
+	return 0;
 }
 
 void TitleDialog::ok_clicked() {
